@@ -7,7 +7,7 @@
 
 from pyxllib.basic import *
 from pyxllib.debug import pd
-from pyxllib.cv import imread, np_array, np
+from pyxllib.cv import np_array, np, PilImg
 
 
 def is_labelme_json_data(data):
@@ -36,7 +36,7 @@ class ToLabelmeJson:
         根据需要可以定制自己的shape，修改get_shape函数
     可以调用write写入文件
 
-    具体用法可以参考 handzuowen https://www.yuque.com/xlpr/datalabel/wzu73p 的数据处理代码
+    document: https://www.yuque.com/xlpr/pyxllib/ks5h4o
     """
 
     def __init__(self, imgpath=None):
@@ -46,29 +46,28 @@ class ToLabelmeJson:
         self.imgpath = File(imgpath)
         # 读取图片数据，在一些转换规则比较复杂，有可能要用到原图数据
         if self.imgpath:
-            self.img = imread(str(self.imgpath))
+            # 一般都只需要获得尺寸，用pil读取即可，速度更快，不需要读取图片rgb数据
+            self.img = PilImg(self.imgpath)
         else:
             self.img = None
-        self.data = None  # 存储json的字典数据
+        self.data = self.get_data_base()  # 存储json的字典数据
 
     def get_data(self, infile):
         """ 格式转换接口函数，继承的类需要自己实现这个方法
 
         :param infile: 待解析的标注数据
         """
-        # s = Path(infile).read()
-        # self.data = self.get_data_base()
         raise NotImplementedError('get_data方法必须在子类中实现')
 
     def get_data_base(self, name='', height=0, width=0):
-        """ 获得一个labelme标注文件的框架
+        """ 获得一个labelme标注文件的框架 （这是标准结构，也可以自己修改定制）
 
         如果初始化时没有输入图片，也可以这里传入name等的值
         """
         # 1 默认属性，和图片名、尺寸
         if self.imgpath:
             name = self.imgpath.name
-            height, width = self.img.shape[:2]
+            height, width = self.img.size
         # 2 构建结构框架
         data = {'version': '4.5.6',
                 'flags': {},
@@ -91,7 +90,9 @@ class ToLabelmeJson:
         # 2 判断形状类型
         if shape_type is None:
             m = len(points)
-            if m == 2:
+            if m == 1:
+                shape_type = 'point'
+            elif m == 2:
                 shape_type = 'rectangle'
             elif m >= 3:
                 shape_type = 'polygon'
@@ -105,6 +106,9 @@ class ToLabelmeJson:
                  'shape_type': shape_type}
         return shape
 
+    def add_shape(self, *args, **kwargs):
+        self.data['shapes'].append(self.get_shape(*args, **kwargs))
+
     def write(self, dst=None, if_exists='delete'):
         """
         :param dst: 往dst目标路径存入json文件，默认名称在self.imgpath同目录的同名json文件
@@ -114,6 +118,52 @@ class ToLabelmeJson:
             dst = self.imgpath.with_suffix('.json')
         return File(dst).write(self.data, if_exists=if_exists)
 
+    @classmethod
+    def create_json(cls, imgpath, annotation):
+        """ 输入图片路径p，和对应的annotation标注数据（一般是对应目录下txt文件） """
+        try:
+            obj = cls(imgpath)
+        except TypeError as e:  # 解析不了的输出错误日志
+            get_xllog().exception(e)
+            return
+        obj.get_data(annotation)
+        obj.write()  # 保存json文件到img对应目录下
+
+    @classmethod
+    def main_normal(cls, imdir, labeldir=None, label_file_suffix='.txt'):
+        """ 封装更高层的接口，输入目录，直接标注目录下所有图片
+
+        :param imdir: 图片路径
+        :param labeldir: 标注数据路径，默认跟imdir同目录
+        :return:
+        """
+        ims = Dir(imdir).select(['*.jpg', '*.png']).subfiles()
+        if not labeldir: labeldir = imdir
+        txts = [File(f.stem, labeldir, suffix=label_file_suffix) for f in ims]
+        cls.main_pair(ims, txts)
+
+    @classmethod
+    def main_pair(cls, images, labels):
+        """ 一一配对匹配处理 """
+        Iterate(zip(images, labels)).run(lambda x: cls.create_json(x[0], x[1]),
+                                         pinterval='20%', max_workers=8)
+
+
+class Quad2Labelme(ToLabelmeJson):
+    """ 四边形类标注转labelme """
+
+    def get_data(self, infile):
+        lines = File(infile).read().splitlines()
+        for line in lines:
+            # 一般是要改这里，每行数据的解析规则
+            vals = line.split(',', maxsplit=8)
+            if len(vals) < 9: continue
+            pts = [int(v) for v in vals[:8]]  # 点集
+            label = vals[-1]  # 标注的文本
+            # get_shape还有shape_type形状参数可以设置
+            #	如果是2个点的矩形，或者3个点以上的多边形，会自动判断，不用指定shape_type
+            self.add_shape(label, pts)
+
 
 def get_labelme_shapes_df(dir, pattern='**/*.json', max_workers=None, pinterval=None, **kwargs):
     """ 获得labelme文件的shapes清单列表
